﻿namespace U2UC.WinUni.Behaviors
{
    using Microsoft.Xaml.Interactivity;
    using System;
    using Windows.UI.Xaml;
    using Windows.UI.Xaml.Controls;

    /// <summary>
    /// A behavior that makes a Border's content disappear when it doesn't entirely fit the screen.
    /// </summary>
    public class ShowAllOrNothingBehavior : DependencyObject, IBehavior
    {
        private Border border;

        public DependencyObject AssociatedObject
        {
            get { return this.border; }
        }

        public void Attach(DependencyObject associatedObject)
        {
            if (associatedObject is Border)
            {
                this.border = associatedObject as Border;
                this.border.SizeChanged += this.Border_SizeChanged;
            }
            else
            {
                throw new Exception("ShowAllOrNothingBehavior Behavior only applies to Border.");
            };
        }

        private void Border_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            if (this.border.IsContentTooWide())
            {
                this.border.Child.Opacity = 0;
            }
            else
            {
                this.border.Child.Opacity = 1;
            }
        }

        public void Detach()
        {
            if (this.border != null)
            {
                this.border.SizeChanged -= this.Border_SizeChanged;
            }
        }
    }
}
